@@ -9,4 +9,11 @@ testthat::test_that("export is correct", {
 
   export_functions <- get_exported_functions(pkg = "base")
   testthat::expect_equal(export_functions[1:5], c("!", "$", "&", "(", "*"))
+  
+  
+  export_functions <- get_exported_functions(pkg = "purrr")
+  testthat::expect_true(all(c("map", "walk", "imap", "pmap") %in%
+                              export_functions))
+  
+  
 })
